/*******************************************************************************
 * Copyright (c) 2006, 2012 Oracle and/or its affiliates. All rights reserved.
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v1.0 and Eclipse Distribution License v. 1.0
 * which accompanies this distribution.
 * The Eclipse Public License is available at http://www.eclipse.org/legal/epl-v10.html
 * and the Eclipse Distribution License is available at
 * http://www.eclipse.org/org/documents/edl-v10.php.
 *
 * Contributors:
 *     Oracle - initial API and implementation
 *
 ******************************************************************************/
package org.eclipse.persistence.tools.mapping.orm;

/**
 * The properties defined for a privately ownabled mapping.
 * <p>
 * Provisional API: This interface is part of an interim API that is still under development and
 * expected to change significantly before reaching stability. It is available at this early stage
 * to solicit feedback from pioneering adopters on the understanding that any code that uses this
 * API will almost certainly be broken (repeatedly) as the API evolves.<p>
 *
 * @see ExternalOneToManyMapping
 * @see ExternalOneToOneMapping
 * @see ExternalVariableOneToOneMapping
 *
 * @version 2.5
 * @author Les Davis
 */
public interface ExternalPrivatelyOwnableMapping extends ExternalForm {

	/**
	 * Returns whether the mapping is private owned.
	 *
	 * @return <code>true</code> if the mapping is privately owned; <code>false</code> otherwise
	 */
	Boolean isPrivateOwned();

	/**
	 * Sets whether the mapping is privately owned.
	 *
	 * @param privateOwned <code>true</code> if the mapping is privately owned; <code>false</code>
	 * otherwise
	 */
	void setPrivateOwned(Boolean privateOwned);
}